==> ksquirrel-trinity_3.5.13.2.orig.tar.xz: ksquirrel-trinity-3.5.13.2/ksquirrel/ksquirrel-libs-configurator/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Dec 03 2007
    copyright            : (C) 2007 by Baryshev Dmitry
    email                : ksquirrel.iv@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kapplication.h>
#include <kcmdlineargs.h>
#include <kaboutdata.h>
#include <kglobal.h>
#include <klocale.h>

#include "klc.h"

static KCmdLineOptions options[] =
{
    KCmdLineLastOption
};

int main(int argc, char *argv[])
{
    const TQCString App = "ksquirrel-libs-configurator";

    KAboutData aboutData(
            "ksquirrel-libs-configurator",
            "ksquirrel-libs-configurator",
            "0.1",
            I18N_NOOP("ksquirrel-libs-configurator"),
            KAboutData::License_GPL,
            "(c) 2007 Baryshev Dmitry",
            TQString(),
            "http://ksquirrel.sourceforge.net",
            "ksquirrel.iv@gmail.com");

    KCmdLineArgs::init(argc, argv, &aboutData);
    KCmdLineArgs::addCmdLineOptions(options);

    KApplication app;

    KGlobal::locale()->insertCatalogue("ksquirrel");
    KGlobal::locale()->setActiveCatalogue("ksquirrel");

    KLC *klc = new KLC(0, App);

    app.setMainWidget(klc);

    klc->show();

    return app.exec();
}

==> ksquirrel-trinity-14.0.12.tar.xz: ksquirrel-trinity-14.0.12/ksquirrel/ksquirrel-libs-configurator/main.cpp <==
/***************************************************************************
                          main.cpp  -  description
                             -------------------
    begin                : Dec 03 2007
    copyright            : (C) 2007 by Baryshev Dmitry
    email                : ksquirrel.iv@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <tdeapplication.h>
#include <tdecmdlineargs.h>
#include <tdeaboutdata.h>
#include <tdeglobal.h>
#include <tdelocale.h>

#include "klc.h"

static TDECmdLineOptions options[] =
{
    TDECmdLineLastOption
};

int main(int argc, char *argv[])
{
    const TQCString App = "ksquirrel-libs-configurator";

    TDEAboutData aboutData(
            "ksquirrel-libs-configurator",
            "ksquirrel-libs-configurator",
            "0.1",
            I18N_NOOP("ksquirrel-libs-configurator"),
            TDEAboutData::License_GPL,
            "(c) 2007 Baryshev Dmitry",
            TQString(),
            "http://ksquirrel.sourceforge.net",
            "ksquirrel.iv@gmail.com");

    TDECmdLineArgs::init(argc, argv, &aboutData);
    TDECmdLineArgs::addCmdLineOptions(options);

    TDEApplication app;

    TDEGlobal::locale()->insertCatalogue("ksquirrel");
    TDEGlobal::locale()->setActiveCatalogue("ksquirrel");

    KLC *klc = new KLC(0, App);

    app.setMainWidget(klc);

    klc->show();

    return app.exec();
}
